# This file was generated by jschema_to_python version 1.1.4.

import attr


@attr.s
class ConfigurationOverride(object):
    """Information about how a specific rule or notification was reconfigured at runtime."""

    configuration = attr.ib()
    descriptor = attr.ib()
    properties = attr.ib(default=None, metadata={"schema_property_name": "properties"})
