# This file was generated by jschema_to_python version 1.1.4.

import attr


@attr.s
class Edge(object):
    """Represents a directed edge in a graph."""

    id = attr.ib()
    source_node_id = attr.ib()
    target_node_id = attr.ib()
    label = attr.ib(default=None, metadata={"schema_property_name": "label"})
    properties = attr.ib(default=None, metadata={"schema_property_name": "properties"})
