# This file was generated by jschema_to_python version 1.1.4.

import attr


@attr.s
class StackFrame(object):
    """A function call within a stack trace."""

    location = attr.ib(default=None, metadata={"schema_property_name": "location"})
    module = attr.ib(default=None, metadata={"schema_property_name": "module"})
    parameters = attr.ib(default=None, metadata={"schema_property_name": "parameters"})
    properties = attr.ib(default=None, metadata={"schema_property_name": "properties"})
    thread_id = attr.ib(default=None, metadata={"schema_property_name": "threadId"})
