# This file was generated by jschema_to_python version 1.1.4.

import attr


@attr.s
class Run(object):
    """Describes a single run of an analysis tool, and contains the reported output of that run."""

    tool = attr.ib()
    addresses = attr.ib(default=None, metadata={"schema_property_name": "addresses"})
    artifacts = attr.ib(default=None, metadata={"schema_property_name": "artifacts"})
    automation_details = attr.ib(default=None, metadata={"schema_property_name": "automationDetails"})
    baseline_guid = attr.ib(default=None, metadata={"schema_property_name": "baselineGuid"})
    column_kind = attr.ib(default=None, metadata={"schema_property_name": "columnKind"})
    conversion = attr.ib(default=None, metadata={"schema_property_name": "conversion"})
    default_encoding = attr.ib(default=None, metadata={"schema_property_name": "defaultEncoding"})
    default_source_language = attr.ib(default=None, metadata={"schema_property_name": "defaultSourceLanguage"})
    external_property_file_references = attr.ib(default=None, metadata={"schema_property_name": "externalPropertyFileReferences"})
    graphs = attr.ib(default=None, metadata={"schema_property_name": "graphs"})
    invocations = attr.ib(default=None, metadata={"schema_property_name": "invocations"})
    language = attr.ib(default="en-US", metadata={"schema_property_name": "language"})
    logical_locations = attr.ib(default=None, metadata={"schema_property_name": "logicalLocations"})
    newline_sequences = attr.ib(default=['\r\n', '\n'], metadata={"schema_property_name": "newlineSequences"})
    original_uri_base_ids = attr.ib(default=None, metadata={"schema_property_name": "originalUriBaseIds"})
    policies = attr.ib(default=None, metadata={"schema_property_name": "policies"})
    properties = attr.ib(default=None, metadata={"schema_property_name": "properties"})
    redaction_tokens = attr.ib(default=None, metadata={"schema_property_name": "redactionTokens"})
    results = attr.ib(default=None, metadata={"schema_property_name": "results"})
    run_aggregates = attr.ib(default=None, metadata={"schema_property_name": "runAggregates"})
    special_locations = attr.ib(default=None, metadata={"schema_property_name": "specialLocations"})
    taxonomies = attr.ib(default=None, metadata={"schema_property_name": "taxonomies"})
    thread_flow_locations = attr.ib(default=None, metadata={"schema_property_name": "threadFlowLocations"})
    translations = attr.ib(default=None, metadata={"schema_property_name": "translations"})
    version_control_provenance = attr.ib(default=None, metadata={"schema_property_name": "versionControlProvenance"})
    web_requests = attr.ib(default=None, metadata={"schema_property_name": "webRequests"})
    web_responses = attr.ib(default=None, metadata={"schema_property_name": "webResponses"})
