# This file was generated by jschema_to_python version 1.1.4.

import attr


@attr.s
class Suppression(object):
    """A suppression that is relevant to a result."""

    kind = attr.ib()
    guid = attr.ib(default=None, metadata={"schema_property_name": "guid"})
    justification = attr.ib(default=None, metadata={"schema_property_name": "justification"})
    location = attr.ib(default=None, metadata={"schema_property_name": "location"})
    properties = attr.ib(default=None, metadata={"schema_property_name": "properties"})
    state = attr.ib(default=None, metadata={"schema_property_name": "state"})
