# This file was generated by jschema_to_python version 1.1.4.

import attr


@attr.s
class ToolComponentReference(object):
    """Identifies a particular toolComponent object, either the driver or an extension."""

    guid = attr.ib(default=None, metadata={"schema_property_name": "guid"})
    index = attr.ib(default=-1, metadata={"schema_property_name": "index"})
    name = attr.ib(default=None, metadata={"schema_property_name": "name"})
    properties = attr.ib(default=None, metadata={"schema_property_name": "properties"})
