# This file was generated by jschema_to_python version 1.1.4.

import attr


@attr.s
class Node(object):
    """Represents a node in a graph."""

    id = attr.ib()
    children = attr.ib(default=None, metadata={"schema_property_name": "children"})
    label = attr.ib(default=None, metadata={"schema_property_name": "label"})
    location = attr.ib(default=None, metadata={"schema_property_name": "location"})
    properties = attr.ib(default=None, metadata={"schema_property_name": "properties"})
