# This file was generated by jschema_to_python version 1.1.4.

import attr


@attr.s
class Result(object):
    """A result produced by an analysis tool."""

    message = attr.ib()
    analysis_target = attr.ib(default=None, metadata={"schema_property_name": "analysisTarget"})
    attachments = attr.ib(default=None, metadata={"schema_property_name": "attachments"})
    baseline_state = attr.ib(default=None, metadata={"schema_property_name": "baselineState"})
    code_flows = attr.ib(default=None, metadata={"schema_property_name": "codeFlows"})
    correlation_guid = attr.ib(default=None, metadata={"schema_property_name": "correlationGuid"})
    fingerprints = attr.ib(default=None, metadata={"schema_property_name": "fingerprints"})
    fixes = attr.ib(default=None, metadata={"schema_property_name": "fixes"})
    graph_traversals = attr.ib(default=None, metadata={"schema_property_name": "graphTraversals"})
    graphs = attr.ib(default=None, metadata={"schema_property_name": "graphs"})
    guid = attr.ib(default=None, metadata={"schema_property_name": "guid"})
    hosted_viewer_uri = attr.ib(default=None, metadata={"schema_property_name": "hostedViewerUri"})
    kind = attr.ib(default="fail", metadata={"schema_property_name": "kind"})
    level = attr.ib(default="warning", metadata={"schema_property_name": "level"})
    locations = attr.ib(default=None, metadata={"schema_property_name": "locations"})
    occurrence_count = attr.ib(default=None, metadata={"schema_property_name": "occurrenceCount"})
    partial_fingerprints = attr.ib(default=None, metadata={"schema_property_name": "partialFingerprints"})
    properties = attr.ib(default=None, metadata={"schema_property_name": "properties"})
    provenance = attr.ib(default=None, metadata={"schema_property_name": "provenance"})
    rank = attr.ib(default=-1.0, metadata={"schema_property_name": "rank"})
    related_locations = attr.ib(default=None, metadata={"schema_property_name": "relatedLocations"})
    rule = attr.ib(default=None, metadata={"schema_property_name": "rule"})
    rule_id = attr.ib(default=None, metadata={"schema_property_name": "ruleId"})
    rule_index = attr.ib(default=-1, metadata={"schema_property_name": "ruleIndex"})
    stacks = attr.ib(default=None, metadata={"schema_property_name": "stacks"})
    suppressions = attr.ib(default=None, metadata={"schema_property_name": "suppressions"})
    taxa = attr.ib(default=None, metadata={"schema_property_name": "taxa"})
    web_request = attr.ib(default=None, metadata={"schema_property_name": "webRequest"})
    web_response = attr.ib(default=None, metadata={"schema_property_name": "webResponse"})
    work_item_uris = attr.ib(default=None, metadata={"schema_property_name": "workItemUris"})
