# This file was generated by jschema_to_python version 1.1.4.

from sarif_om._sarif_log import SarifLog
from sarif_om._address import Address
from sarif_om._artifact import Artifact
from sarif_om._artifact_change import ArtifactChange
from sarif_om._artifact_content import ArtifactContent
from sarif_om._artifact_location import ArtifactLocation
from sarif_om._attachment import Attachment
from sarif_om._code_flow import CodeFlow
from sarif_om._configuration_override import ConfigurationOverride
from sarif_om._conversion import Conversion
from sarif_om._edge import Edge
from sarif_om._edge_traversal import EdgeTraversal
from sarif_om._exception import Exception
from sarif_om._external_properties import ExternalProperties
from sarif_om._external_property_file_reference import ExternalPropertyFileReference
from sarif_om._external_property_file_references import ExternalPropertyFileReferences
from sarif_om._fix import Fix
from sarif_om._graph import Graph
from sarif_om._graph_traversal import GraphTraversal
from sarif_om._invocation import Invocation
from sarif_om._location import Location
from sarif_om._location_relationship import LocationRelationship
from sarif_om._logical_location import LogicalLocation
from sarif_om._message import Message
from sarif_om._multiformat_message_string import MultiformatMessageString
from sarif_om._node import Node
from sarif_om._notification import Notification
from sarif_om._physical_location import PhysicalLocation
from sarif_om._property_bag import PropertyBag
from sarif_om._rectangle import Rectangle
from sarif_om._region import Region
from sarif_om._replacement import Replacement
from sarif_om._reporting_configuration import ReportingConfiguration
from sarif_om._reporting_descriptor import ReportingDescriptor
from sarif_om._reporting_descriptor_reference import ReportingDescriptorReference
from sarif_om._reporting_descriptor_relationship import ReportingDescriptorRelationship
from sarif_om._result import Result
from sarif_om._result_provenance import ResultProvenance
from sarif_om._run import Run
from sarif_om._run_automation_details import RunAutomationDetails
from sarif_om._special_locations import SpecialLocations
from sarif_om._stack import Stack
from sarif_om._stack_frame import StackFrame
from sarif_om._suppression import Suppression
from sarif_om._thread_flow import ThreadFlow
from sarif_om._thread_flow_location import ThreadFlowLocation
from sarif_om._tool import Tool
from sarif_om._tool_component import ToolComponent
from sarif_om._tool_component_reference import ToolComponentReference
from sarif_om._translation_metadata import TranslationMetadata
from sarif_om._version_control_details import VersionControlDetails
from sarif_om._web_request import WebRequest
from sarif_om._web_response import WebResponse
