# This file was generated by jschema_to_python version 1.1.4.

import attr


@attr.s
class ReportingConfiguration(object):
    """Information about a rule or notification that can be configured at runtime."""

    enabled = attr.ib(default=True, metadata={"schema_property_name": "enabled"})
    level = attr.ib(default="warning", metadata={"schema_property_name": "level"})
    parameters = attr.ib(default=None, metadata={"schema_property_name": "parameters"})
    properties = attr.ib(default=None, metadata={"schema_property_name": "properties"})
    rank = attr.ib(default=-1.0, metadata={"schema_property_name": "rank"})
