# This file was generated by jschema_to_python version 1.1.4.

import attr


@attr.s
class Stack(object):
    """A call stack that is relevant to a result."""

    frames = attr.ib()
    message = attr.ib(default=None, metadata={"schema_property_name": "message"})
    properties = attr.ib(default=None, metadata={"schema_property_name": "properties"})
